#' Normalized and subsetted soybean cotyledon SummarizedExperiment object
#' 
#' @name se_soybean_cn_sub
#' @title Normalized and subsetted soybean cotyledon SummarizedExperiment
#' @description This dataset contains normalized RNA-sequencing read counts 
#' from soybean cotyledon across three time stages of development. Early 
#' stage cotyledons were collected four days after planting and were green 
#' but closed. Middle stage cotyledons were collected while green and open, 
#' soon after the plant generated its first set of unifoliate leaves. Late 
#' stage cotyledons were collected immediately after the initiation of 
#' yellowing and shrinking. To save on size, this example dataset was 
#' generated by obtaining a random subset of 1 out of 10 genes from the 
#' original resource.
#' @docType data
#' @format (1) A DelayedMatrix with 7,332 rows and 10 variables and 1 row per
#'  gene. Accessible by \code{assay(se_soybean_cn_sub)}. (2) A List with 1
#'  list element per treatment group combination and 1 row per gene.
#'  Accessible by \code{rowData(se_soybean_cn_sub)}.
#' @details 
#' \itemize{
    #' \item \code{assay(se_soybean_cn_sub)} Structure:
    #' \item S1.1 early stage replicate 1 normalized read counts
    #' \item S1.2 early stage replicate 2 normalized read counts
    #' \item S1.3 early stage replicate 3 normalized read counts
    #' \item S2.1 middle stage replicate 1 normalized read counts
    #' \item S2.2 middle stage replicate 2 normalized read counts
    #' \item S2.3 middle stage replicate 3 normalized read counts
    #' \item S3.1 late stage replicate 1 normalized read counts
    #' \item S3.2 late stage replicate 2 normalized read counts
    #' \item S3.3 late stage replicate 3 normalized read counts
    #' }
    #' 
#' \itemize{
#' \item \code{rowData(se_soybean_cn_sub)} list element Structure:
#' \item ID gene name
#' \item logFC log fold change
#' \item logCPM log counts per million
#' \item LR likelihood ratio
#' \item PValue p-value
#' \item FDR FDR value
#' }
#' @docType data
#' @keywords datasets
#' @usage data(se_soybean_cn_sub)
#' @seealso \code{\link{soybean_cn_sub}} and
#' \code{\link{soybean_cn_sub_metrics}}
#' @references
#' Brown AV, Hudson KA (2015) Developmental profiling of gene expression in 
#' soybean trifoliate leaves and cotyledons. BMC Plant Biol 15:169
NULL
